All Classes and Interfaces
Class
Description
Structure that contains the results of the account gate function which CloudFormation invokes, if present, before
proceeding with a StackSet operation in an account and Region.
Describes the current CloudFormation limits for your account.
ActivateOrganizationsAccessRequest MarshallerActivateTypeRequest Marshaller
The resource with the name requested already exists.
The
Annotation data type.An AWS Arn.
Describes whether StackSets automatically deploys to Organizations accounts that are added to a target organization
or organizational unit (OU).
Detailed information concerning an error generated during the setting of configuration data for a CloudFormation
extension.
BatchDescribeTypeConfigurationsRequest Marshaller
The input for the CancelUpdateStack action.
CancelUpdateStackRequest Marshaller
An error occurred during a CloudFormation registry operation.
The
Change structure describes the changes CloudFormation will perform if you execute the change set.
Specifies the resource, the Hook, and the Hook version to be invoked.
Specifies
RESOURCE type target details for activated Hooks.
Specifies target details for an activated Hook.
The specified change set name or ID doesn't exit.
The
ChangeSetSummary structure describes a change set, its status, and the stack with which it's
associated.Service client for accessing AWS CloudFormation asynchronously.
A builder for creating an instance of
CloudFormationAsyncClient.Waiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
The parameters object used to resolve the auth schemes for the CloudFormation service.
A builder for a
CloudFormationAuthSchemeParams.An auth scheme provider for CloudFormation service.
This includes configuration specific to AWS CloudFormation that is supported by both
CloudFormationClientBuilder and CloudFormationAsyncClientBuilder.Service client for accessing AWS CloudFormation.
A builder for creating an instance of
CloudFormationClient.The parameters object used to resolve an endpoint for the CloudFormation service.
An endpoint provider for CloudFormation.
Class to expose the service client settings to the user.
A builder for creating a
CloudFormationServiceClientConfigurationWaiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
No more than 5 generated templates can be in an
InProgress or Pending status at one time.
The input for the ContinueUpdateRollback action.
ContinueUpdateRollbackRequest Marshaller
The output for a ContinueUpdateRollback operation.
The input for the CreateChangeSet action.
CreateChangeSetRequest Marshaller
The output for the CreateChangeSet action.
The specified resource exists, but has been changed.
CreateGeneratedTemplateRequest MarshallerCreateStackInstancesRequest MarshallerCreateStackRefactorRequest Marshaller
The input for CreateStack action.
CreateStackRequest Marshaller
The output for a CreateStack action.
CreateStackSetRequest MarshallerDeactivateOrganizationsAccessRequest MarshallerDeactivateTypeRequest Marshaller
The input for the DeleteChangeSet action.
DeleteChangeSetRequest Marshaller
The output for the DeleteChangeSet action.
DeleteGeneratedTemplateRequest MarshallerDeleteStackInstancesRequest Marshaller
The input for DeleteStack action.
DeleteStackRequest MarshallerDeleteStackSetRequest Marshaller
The deployment configuration for a stack operation, including the deployment mode.
Specifies the Organizations accounts where you want to create, update, or delete stack instances.
DeregisterTypeRequest Marshaller
Represents the output for the
CloudFormationClient.describeAccountLimitsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeAccountLimitsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeAccountLimitsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeAccountLimitsRequest)
operation which is a paginated operation.
The input for the DescribeAccountLimits action.
DescribeAccountLimitsRequest Marshaller
The output for the DescribeAccountLimits action.
DescribeChangeSetHooksRequest Marshaller
Represents the output for the
CloudFormationClient.describeChangeSetPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeChangeSetRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeChangeSetPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeChangeSetRequest)
operation which is a paginated operation.
The input for the DescribeChangeSet action.
DescribeChangeSetRequest Marshaller
The output for the DescribeChangeSet action.
Represents the output for the
CloudFormationClient.describeEventsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeEventsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeEventsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeEventsRequest)
operation which is a paginated operation.DescribeEventsRequest MarshallerDescribeGeneratedTemplateRequest MarshallerDescribeOrganizationsAccessRequest MarshallerDescribePublisherRequest MarshallerDescribeResourceScanRequest MarshallerDescribeStackDriftDetectionStatusRequest Marshaller
Represents the output for the
CloudFormationClient.describeStackEventsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStackEventsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeStackEventsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStackEventsRequest)
operation which is a paginated operation.
The input for DescribeStackEvents action.
DescribeStackEventsRequest Marshaller
The output for a DescribeStackEvents action.
DescribeStackInstanceRequest MarshallerDescribeStackRefactorRequest Marshaller
Represents the output for the
CloudFormationClient.describeStackResourceDriftsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStackResourceDriftsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeStackResourceDriftsPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStackResourceDriftsRequest)
operation which is a paginated operation.DescribeStackResourceDriftsRequest Marshaller
The input for DescribeStackResource action.
DescribeStackResourceRequest Marshaller
The output for a DescribeStackResource action.
The input for DescribeStackResources action.
DescribeStackResourcesRequest Marshaller
The output for a DescribeStackResources action.
DescribeStackSetOperationRequest MarshallerDescribeStackSetRequest Marshaller
Represents the output for the
CloudFormationClient.describeStacksPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStacksRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.describeStacksPaginator(software.amazon.awssdk.services.cloudformation.model.DescribeStacksRequest)
operation which is a paginated operation.
The input for DescribeStacks action.
DescribeStacksRequest Marshaller
The output for a DescribeStacks action.
DescribeTypeRegistrationRequest MarshallerDescribeTypeRequest MarshallerDetectStackDriftRequest MarshallerDetectStackResourceDriftRequest MarshallerDetectStackSetDriftRequest MarshallerLink between an endpoint property and the
AwsEndpointAttribute it represents.
The input for an EstimateTemplateCost action.
EstimateTemplateCostRequest Marshaller
The output for a EstimateTemplateCost action.
Event filter allows you to focus on specific events in an operation.
The input for the ExecuteChangeSet action.
ExecuteChangeSetRequest Marshaller
The output for the ExecuteChangeSet action.
ExecuteStackRefactorRequest Marshaller
The
Export structure describes the exported output values for a stack.
The generated template was not found.
GetGeneratedTemplateRequest MarshallerGetHookResultRequest Marshaller
The input for the GetStackPolicy action.
GetStackPolicyRequest Marshaller
The output for the GetStackPolicy action.
The input for a GetTemplate action.
GetTemplateRequest Marshaller
The output for GetTemplate action.
The input for the GetTemplateSummary action.
GetTemplateSummaryRequest Marshaller
The output for the GetTemplateSummary action.
The specified target doesn't have any requested Hook invocations.
A
ListHookResults call returns a summary of a Hook invocation.
The
HookTarget data type.Identifiers for variables declared within the rule engine, e.g.
ImportStacksToStackSetRequest Marshaller
The template contains resources with capabilities that weren't specified in the Capabilities parameter.
The specified change set can't be used to update the stack.
The specified operation isn't valid.
Error reserved for use by the CloudFormation
CLI.
An intermediate value for JMESPath expressions, encapsulating the different data types supported by JMESPath and
the operations on that data.
The quota for the resource has already been reached.
Represents the output for the
CloudFormationClient.listChangeSetsPaginator(software.amazon.awssdk.services.cloudformation.model.ListChangeSetsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listChangeSetsPaginator(software.amazon.awssdk.services.cloudformation.model.ListChangeSetsRequest)
operation which is a paginated operation.
The input for the ListChangeSets action.
ListChangeSetsRequest Marshaller
The output for the ListChangeSets action.
Represents the output for the
CloudFormationClient.listExportsPaginator(software.amazon.awssdk.services.cloudformation.model.ListExportsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listExportsPaginator(software.amazon.awssdk.services.cloudformation.model.ListExportsRequest)
operation which is a paginated operation.ListExportsRequest Marshaller
Represents the output for the
CloudFormationClient.listGeneratedTemplatesPaginator(software.amazon.awssdk.services.cloudformation.model.ListGeneratedTemplatesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listGeneratedTemplatesPaginator(software.amazon.awssdk.services.cloudformation.model.ListGeneratedTemplatesRequest)
operation which is a paginated operation.ListGeneratedTemplatesRequest MarshallerListHookResultsRequest Marshaller
Represents the output for the
CloudFormationClient.listImportsPaginator(software.amazon.awssdk.services.cloudformation.model.ListImportsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listImportsPaginator(software.amazon.awssdk.services.cloudformation.model.ListImportsRequest)
operation which is a paginated operation.ListImportsRequest Marshaller
Represents the output for the
CloudFormationClient.listResourceScanRelatedResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScanRelatedResourcesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listResourceScanRelatedResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScanRelatedResourcesRequest)
operation which is a paginated operation.ListResourceScanRelatedResourcesRequest Marshaller
Represents the output for the
CloudFormationClient.listResourceScanResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScanResourcesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listResourceScanResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScanResourcesRequest)
operation which is a paginated operation.ListResourceScanResourcesRequest Marshaller
Represents the output for the
CloudFormationClient.listResourceScansPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScansRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listResourceScansPaginator(software.amazon.awssdk.services.cloudformation.model.ListResourceScansRequest)
operation which is a paginated operation.ListResourceScansRequest MarshallerListStackInstanceResourceDriftsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackInstancesPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackInstancesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackInstancesPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackInstancesRequest)
operation which is a paginated operation.ListStackInstancesRequest Marshaller
Represents the output for the
CloudFormationClient.listStackRefactorActionsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackRefactorActionsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackRefactorActionsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackRefactorActionsRequest)
operation which is a paginated operation.ListStackRefactorActionsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackRefactorsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackRefactorsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackRefactorsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackRefactorsRequest)
operation which is a paginated operation.ListStackRefactorsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackResourcesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackResourcesPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackResourcesRequest)
operation which is a paginated operation.
The input for the ListStackResource action.
ListStackResourcesRequest Marshaller
The output for a ListStackResources action.
ListStackSetAutoDeploymentTargetsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackSetOperationResultsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackSetOperationResultsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationResultsRequest)
operation which is a paginated operation.ListStackSetOperationResultsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackSetOperationsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackSetOperationsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetOperationsRequest)
operation which is a paginated operation.ListStackSetOperationsRequest Marshaller
Represents the output for the
CloudFormationClient.listStackSetsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStackSetsPaginator(software.amazon.awssdk.services.cloudformation.model.ListStackSetsRequest)
operation which is a paginated operation.ListStackSetsRequest Marshaller
Represents the output for the
CloudFormationClient.listStacksPaginator(software.amazon.awssdk.services.cloudformation.model.ListStacksRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listStacksPaginator(software.amazon.awssdk.services.cloudformation.model.ListStacksRequest)
operation which is a paginated operation.
The input for ListStacks action.
ListStacksRequest Marshaller
The output for ListStacks action.
Represents the output for the
CloudFormationClient.listTypeRegistrationsPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypeRegistrationsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listTypeRegistrationsPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypeRegistrationsRequest)
operation which is a paginated operation.ListTypeRegistrationsRequest Marshaller
Represents the output for the
CloudFormationClient.listTypesPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypesRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listTypesPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypesRequest)
operation which is a paginated operation.ListTypesRequest Marshaller
Represents the output for the
CloudFormationClient.listTypeVersionsPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypeVersionsRequest)
operation which is a paginated operation.
Represents the output for the
CloudFormationAsyncClient.listTypeVersionsPaginator(software.amazon.awssdk.services.cloudformation.model.ListTypeVersionsRequest)
operation which is a paginated operation.ListTypeVersionsRequest Marshaller
Contains drift information for a resource property, including actual value, previous deployment value, and drift
detection timestamp.
Contains logging configuration information for an extension.
Describes whether StackSets performs non-conflicting operations concurrently and queues conflicting operations.
Contains information about the module from which the resource was created, if the resource was created from a module
included in the stack template.
The specified name is already in use.
Contains information about a CloudFormation operation.
Contains detailed information about an event that occurred during a CloudFormation operation.
The specified operation ID already exists.
Another operation is currently in progress for this StackSet.
The specified ID refers to an operation that doesn't exist.
The status that operation results are filtered by.
Error reserved for use by the CloudFormation
CLI.
The
Output data type.
The
Parameter data type.
A set of criteria that CloudFormation uses to validate parameter values.
The
ParameterDeclaration data type.
Context information that enables CloudFormation to uniquely identify a resource.
Information about a resource property whose actual value differs from its expected value, as defined in the stack
template and any values specified as template parameters.
PublishTypeRequest MarshallerRecordHandlerProgressRequest MarshallerRegisterPublisherRequest MarshallerRegisterTypeRequest Marshaller
For extensions that are modules, a public third-party extension that must be activated in your account in order for
the module itself to be activated.
The
ResourceChange structure describes the resource and the action that CloudFormation will perform on
it if you execute this change set.
For a resource with
Modify as the action, the ResourceChange structure describes the
changes CloudFormation will make to that resource.
A resource included in a generated template.
Details about a resource in a generated template
The
ResourceDriftIgnoredAttribute data type.
Describes the target resources of a specific type in your import template (for example, all
AWS::S3::Bucket resources) and the properties you can provide during the import to identify resources of
that type.
The location of the resource in a stack template.
Specifies the current source of the resource and the destination of where it will be moved to.
A resource scan is currently in progress.
The limit on resource scans has been exceeded.
The resource scan was not found.
A summary of the resource scan.
The field that CloudFormation will change, such as the name of a resource's property, and whether the resource will
be recreated.
Describes the target resource of an import operation.
Structure that contains the rollback triggers for CloudFormation to monitor during stack creation and updating
operations, and for the specified monitoring period afterwards.
RollbackStackRequest Marshaller
A rollback trigger CloudFormation monitors during creation and updating of stacks.
Represents a URL to be used internally for endpoint resolution.
A filter that is used to specify which resource types to scan.
A scanned resource returned by
ListResourceScanResources or
ListResourceScanRelatedResources.
Identifies a scanned resource.
The input for the SetStackPolicy action.
SetStackPolicyRequest MarshallerSetTypeConfigurationRequest MarshallerSetTypeDefaultVersionRequest Marshaller
The input for the SignalResource action.
SignalResourceRequest Marshaller
The
Stack data type.
Describes the stack and the template used by the stack.
Contains information about whether the stack's actual configuration differs, or has drifted, from its expected
configuration, as defined in the stack template and any values specified as template parameters.
Contains information about whether the stack's actual configuration differs, or has drifted, from its expected
configuration, as defined in the stack template and any values specified as template parameters.
The
StackEvent data type.
A CloudFormation stack, in a specific account and Region, that's part of a StackSet operation.
The detailed status of the stack instance.
The filter to apply to stack instances
The specified stack instance doesn't exist.
The structure containing summary information about resource drifts for a stack instance.
The structure that contains summary information about a stack instance.
The specified stack ARN doesn't exist or stack doesn't exist corresponding to the ARN in input.
Describes the stack and the action that CloudFormation will perform on it if you execute the stack refactor.
The specified stack refactor can't be found.
The summary of a stack refactor operation.
The
StackResource data type.
Contains detailed information about the specified stack resource.
Contains the drift information for a resource that has been checked for drift.
Contains information about whether the resource's actual configuration differs, or has drifted, from its
expected configuration.
Summarizes information about whether the resource's actual configuration differs, or has drifted, from its
expected configuration.
Contains high-level information about the specified stack resource.
A structure that contains information about a StackSet.
One of the targets for the StackSet.
Detailed information about the drift status of the StackSet.
You can't yet delete this StackSet, because it still contains one or more stack instances.
The specified StackSet doesn't exist.
The structure that contains information about a StackSet operation.
The user-specified preferences for how CloudFormation performs a StackSet operation.
The structure that contains information about a specified operation's results for a given account in a given Region.
Detailed information about the StackSet operation.
The structures that contain summary information about the specified operation.
The structures that contain summary information about the specified StackSet.
The
StackSummary Data Type
Another operation has been performed on this StackSet since the specified operation was performed.
StartResourceScanRequest MarshallerStopStackSetOperationRequest Marshaller
The Tag type enables you to specify a key-value pair that can be used to store information about an CloudFormation
stack.
The configuration details of a generated template.
The
TemplateParameter data type.
A summary of the progress of the template generation.
The summary of a generated template.
Options for the
GetTemplateSummary API action.TestTypeRequest Marshaller
A client request token already exists.
Detailed information concerning the specification of a CloudFormation extension in a given account and Region.
Identifying information for the configuration of a CloudFormation extension.
The specified extension configuration can't be found.
Filter criteria to use in determining which extensions to return.
The specified extension doesn't exist in the CloudFormation registry.
Contains summary information about the specified CloudFormation extension.
Contains summary information about a specific version of a CloudFormation extension.
UpdateGeneratedTemplateRequest MarshallerUpdateStackInstancesRequest Marshaller
The input for an UpdateStack action.
UpdateStackRequest Marshaller
The output for an UpdateStack action.
UpdateStackSetRequest MarshallerUpdateTerminationProtectionRequest Marshaller
The input for ValidateTemplate action.
ValidateTemplateRequest Marshaller
The output for ValidateTemplate action.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Contains classes used at runtime by the code generator classes for waiter acceptors generated from JMESPath
expressions.
A
WaiterAcceptor implementation that checks for a specific HTTP response status, regardless of whether
it's reported by a response or an exception.
The warnings generated for a specific resource for this generated template.
A specific property that is impacted by a warning.
Contains any warnings returned by the
GetTemplateSummary API action.