Class CreateStackResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.cloudformation.model.CloudFormationResponse
software.amazon.awssdk.services.cloudformation.model.CreateStackResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateStackResponse.Builder,CreateStackResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CreateStackResponse
extends CloudFormationResponse
implements ToCopyableBuilder<CreateStackResponse.Builder,CreateStackResponse>
The output for a CreateStack action.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CreateStackResponse.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringA unique identifier for this stack operation that can be used to track the operation's progress and events.static Class<? extends CreateStackResponse.Builder>final StringstackId()Unique identifier of the stack.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.cloudformation.model.CloudFormationResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
stackId
Unique identifier of the stack.
- Returns:
- Unique identifier of the stack.
-
operationId
A unique identifier for this stack operation that can be used to track the operation's progress and events.
- Returns:
- A unique identifier for this stack operation that can be used to track the operation's progress and events.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateStackResponse.Builder,CreateStackResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-