Class DescribeStackRefactorRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudformation.model.CloudFormationRequest
software.amazon.awssdk.services.cloudformation.model.DescribeStackRefactorRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeStackRefactorRequest.Builder,DescribeStackRefactorRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeStackRefactorRequest
extends CloudFormationRequest
implements ToCopyableBuilder<DescribeStackRefactorRequest.Builder,DescribeStackRefactorRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DescribeStackRefactorRequest.Builder>final StringThe ID associated with the stack refactor created from the CreateStackRefactor action.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
stackRefactorId
The ID associated with the stack refactor created from the CreateStackRefactor action.
- Returns:
- The ID associated with the stack refactor created from the CreateStackRefactor action.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeStackRefactorRequest.Builder,DescribeStackRefactorRequest> - Specified by:
toBuilderin classCloudFormationRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-