Class DescribeStackSetRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DescribeStackSetRequest.Builder,DescribeStackSetRequest>

@Generated("software.amazon.awssdk:codegen") public final class DescribeStackSetRequest extends CloudFormationRequest implements ToCopyableBuilder<DescribeStackSetRequest.Builder,DescribeStackSetRequest>
  • Method Details

    • stackSetName

      public final String stackSetName()

      The name or unique ID of the StackSet whose description you want.

      Returns:
      The name or unique ID of the StackSet whose description you want.
    • callAs

      public final CallAs callAs()

      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      If the service returns an enum value that is not available in the current SDK version, callAs will return CallAs.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from callAsAsString().

      Returns:
      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      See Also:
    • callAsAsString

      public final String callAsAsString()

      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      If the service returns an enum value that is not available in the current SDK version, callAs will return CallAs.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from callAsAsString().

      Returns:
      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      See Also:
    • toBuilder

      public DescribeStackSetRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<DescribeStackSetRequest.Builder,DescribeStackSetRequest>
      Specified by:
      toBuilder in class CloudFormationRequest
    • builder

      public static DescribeStackSetRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DescribeStackSetRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo