Interface DescribeStackSetRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CloudFormationRequest.Builder, CopyableBuilder<DescribeStackSetRequest.Builder,DescribeStackSetRequest>, SdkBuilder<DescribeStackSetRequest.Builder,DescribeStackSetRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
DescribeStackSetRequest

  • Method Details

    • stackSetName

      DescribeStackSetRequest.Builder stackSetName(String stackSetName)

      The name or unique ID of the StackSet whose description you want.

      Parameters:
      stackSetName - The name or unique ID of the StackSet whose description you want.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • callAs

      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      Parameters:
      callAs - [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • callAs

      [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      Parameters:
      callAs - [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

      By default, SELF is specified. Use SELF for StackSets with self-managed permissions.

      • If you are signed in to the management account, specify SELF.

      • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

        Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • overrideConfiguration

      DescribeStackSetRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder