Interface DescribeStackSetRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CloudFormationRequest.Builder,CopyableBuilder<DescribeStackSetRequest.Builder,,DescribeStackSetRequest> SdkBuilder<DescribeStackSetRequest.Builder,,DescribeStackSetRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- DescribeStackSetRequest
-
Method Summary
Modifier and TypeMethodDescription[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) stackSetName(String stackSetName) The name or unique ID of the StackSet whose description you want.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.cloudformation.model.CloudFormationRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
stackSetName
The name or unique ID of the StackSet whose description you want.
- Parameters:
stackSetName- The name or unique ID of the StackSet whose description you want.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
callAs
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
- Parameters:
callAs- [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
-
callAs
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
- Parameters:
callAs- [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
-
overrideConfiguration
DescribeStackSetRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeStackSetRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-