Class StopStackSetOperationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<StopStackSetOperationRequest.Builder,StopStackSetOperationRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final CallAscallAs()Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.final StringSpecifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ID of the stack operation.static Class<? extends StopStackSetOperationRequest.Builder>final StringThe name or unique ID of the StackSet that you want to stop the operation for.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
stackSetName
The name or unique ID of the StackSet that you want to stop the operation for.
- Returns:
- The name or unique ID of the StackSet that you want to stop the operation for.
-
operationId
The ID of the stack operation.
- Returns:
- The ID of the stack operation.
-
callAs
Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. Valid only if the StackSet uses service-managed permissions.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
If the service returns an enum value that is not available in the current SDK version,
callAswill returnCallAs.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcallAsAsString().- Returns:
- Specifies whether you are acting as an account administrator in the organization's management account or
as a delegated administrator in a member account. Valid only if the StackSet uses service-managed
permissions.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
-
- See Also:
-
-
callAsAsString
Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. Valid only if the StackSet uses service-managed permissions.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
If the service returns an enum value that is not available in the current SDK version,
callAswill returnCallAs.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcallAsAsString().- Returns:
- Specifies whether you are acting as an account administrator in the organization's management account or
as a delegated administrator in a member account. Valid only if the StackSet uses service-managed
permissions.
By default,
SELFis specified. UseSELFfor StackSets with self-managed permissions.-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
-
- See Also:
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StopStackSetOperationRequest.Builder,StopStackSetOperationRequest> - Specified by:
toBuilderin classCloudFormationRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-